# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseInsightSummary(object):
    """
    Summary of a database insight resource.
    """

    #: A constant which can be used with the entity_source property of a DatabaseInsightSummary.
    #: This constant has a value of "AUTONOMOUS_DATABASE"
    ENTITY_SOURCE_AUTONOMOUS_DATABASE = "AUTONOMOUS_DATABASE"

    #: A constant which can be used with the entity_source property of a DatabaseInsightSummary.
    #: This constant has a value of "EM_MANAGED_EXTERNAL_DATABASE"
    ENTITY_SOURCE_EM_MANAGED_EXTERNAL_DATABASE = "EM_MANAGED_EXTERNAL_DATABASE"

    #: A constant which can be used with the entity_source property of a DatabaseInsightSummary.
    #: This constant has a value of "MACS_MANAGED_EXTERNAL_DATABASE"
    ENTITY_SOURCE_MACS_MANAGED_EXTERNAL_DATABASE = "MACS_MANAGED_EXTERNAL_DATABASE"

    #: A constant which can be used with the status property of a DatabaseInsightSummary.
    #: This constant has a value of "DISABLED"
    STATUS_DISABLED = "DISABLED"

    #: A constant which can be used with the status property of a DatabaseInsightSummary.
    #: This constant has a value of "ENABLED"
    STATUS_ENABLED = "ENABLED"

    #: A constant which can be used with the status property of a DatabaseInsightSummary.
    #: This constant has a value of "TERMINATED"
    STATUS_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a DatabaseInsightSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a DatabaseInsightSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a DatabaseInsightSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a DatabaseInsightSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a DatabaseInsightSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a DatabaseInsightSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a DatabaseInsightSummary.
    #: This constant has a value of "NEEDS_ATTENTION"
    LIFECYCLE_STATE_NEEDS_ATTENTION = "NEEDS_ATTENTION"

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseInsightSummary object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.opsi.models.MacsManagedExternalDatabaseInsightSummary`
        * :class:`~oci.opsi.models.AutonomousDatabaseInsightSummary`
        * :class:`~oci.opsi.models.EmManagedExternalDatabaseInsightSummary`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DatabaseInsightSummary.
        :type id: str

        :param database_id:
            The value to assign to the database_id property of this DatabaseInsightSummary.
        :type database_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DatabaseInsightSummary.
        :type compartment_id: str

        :param database_name:
            The value to assign to the database_name property of this DatabaseInsightSummary.
        :type database_name: str

        :param database_display_name:
            The value to assign to the database_display_name property of this DatabaseInsightSummary.
        :type database_display_name: str

        :param database_type:
            The value to assign to the database_type property of this DatabaseInsightSummary.
        :type database_type: str

        :param database_version:
            The value to assign to the database_version property of this DatabaseInsightSummary.
        :type database_version: str

        :param database_host_names:
            The value to assign to the database_host_names property of this DatabaseInsightSummary.
        :type database_host_names: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DatabaseInsightSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this DatabaseInsightSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this DatabaseInsightSummary.
        :type system_tags: dict(str, dict(str, object))

        :param entity_source:
            The value to assign to the entity_source property of this DatabaseInsightSummary.
            Allowed values for this property are: "AUTONOMOUS_DATABASE", "EM_MANAGED_EXTERNAL_DATABASE", "MACS_MANAGED_EXTERNAL_DATABASE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_source: str

        :param processor_count:
            The value to assign to the processor_count property of this DatabaseInsightSummary.
        :type processor_count: int

        :param status:
            The value to assign to the status property of this DatabaseInsightSummary.
            Allowed values for this property are: "DISABLED", "ENABLED", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param time_created:
            The value to assign to the time_created property of this DatabaseInsightSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DatabaseInsightSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DatabaseInsightSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DatabaseInsightSummary.
        :type lifecycle_details: str

        """
        self.swagger_types = {
            'id': 'str',
            'database_id': 'str',
            'compartment_id': 'str',
            'database_name': 'str',
            'database_display_name': 'str',
            'database_type': 'str',
            'database_version': 'str',
            'database_host_names': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'entity_source': 'str',
            'processor_count': 'int',
            'status': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'database_id': 'databaseId',
            'compartment_id': 'compartmentId',
            'database_name': 'databaseName',
            'database_display_name': 'databaseDisplayName',
            'database_type': 'databaseType',
            'database_version': 'databaseVersion',
            'database_host_names': 'databaseHostNames',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'entity_source': 'entitySource',
            'processor_count': 'processorCount',
            'status': 'status',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails'
        }

        self._id = None
        self._database_id = None
        self._compartment_id = None
        self._database_name = None
        self._database_display_name = None
        self._database_type = None
        self._database_version = None
        self._database_host_names = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._entity_source = None
        self._processor_count = None
        self._status = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['entitySource']

        if type == 'MACS_MANAGED_EXTERNAL_DATABASE':
            return 'MacsManagedExternalDatabaseInsightSummary'

        if type == 'AUTONOMOUS_DATABASE':
            return 'AutonomousDatabaseInsightSummary'

        if type == 'EM_MANAGED_EXTERNAL_DATABASE':
            return 'EmManagedExternalDatabaseInsightSummary'
        else:
            return 'DatabaseInsightSummary'

    @property
    def id(self):
        """
        **[Required]** Gets the id of this DatabaseInsightSummary.
        The `OCID`__ of the database insight resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DatabaseInsightSummary.
        The `OCID`__ of the database insight resource.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this DatabaseInsightSummary.
        :type: str
        """
        self._id = id

    @property
    def database_id(self):
        """
        **[Required]** Gets the database_id of this DatabaseInsightSummary.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The database_id of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_id

    @database_id.setter
    def database_id(self, database_id):
        """
        Sets the database_id of this DatabaseInsightSummary.
        The `OCID`__ of the database.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param database_id: The database_id of this DatabaseInsightSummary.
        :type: str
        """
        self._database_id = database_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this DatabaseInsightSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this DatabaseInsightSummary.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this DatabaseInsightSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def database_name(self):
        """
        Gets the database_name of this DatabaseInsightSummary.
        The database name. The database name is unique within the tenancy.


        :return: The database_name of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_name

    @database_name.setter
    def database_name(self, database_name):
        """
        Sets the database_name of this DatabaseInsightSummary.
        The database name. The database name is unique within the tenancy.


        :param database_name: The database_name of this DatabaseInsightSummary.
        :type: str
        """
        self._database_name = database_name

    @property
    def database_display_name(self):
        """
        Gets the database_display_name of this DatabaseInsightSummary.
        The user-friendly name for the database. The name does not have to be unique.


        :return: The database_display_name of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_display_name

    @database_display_name.setter
    def database_display_name(self, database_display_name):
        """
        Sets the database_display_name of this DatabaseInsightSummary.
        The user-friendly name for the database. The name does not have to be unique.


        :param database_display_name: The database_display_name of this DatabaseInsightSummary.
        :type: str
        """
        self._database_display_name = database_display_name

    @property
    def database_type(self):
        """
        Gets the database_type of this DatabaseInsightSummary.
        Operations Insights internal representation of the database type.


        :return: The database_type of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_type

    @database_type.setter
    def database_type(self, database_type):
        """
        Sets the database_type of this DatabaseInsightSummary.
        Operations Insights internal representation of the database type.


        :param database_type: The database_type of this DatabaseInsightSummary.
        :type: str
        """
        self._database_type = database_type

    @property
    def database_version(self):
        """
        Gets the database_version of this DatabaseInsightSummary.
        The version of the database.


        :return: The database_version of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._database_version

    @database_version.setter
    def database_version(self, database_version):
        """
        Sets the database_version of this DatabaseInsightSummary.
        The version of the database.


        :param database_version: The database_version of this DatabaseInsightSummary.
        :type: str
        """
        self._database_version = database_version

    @property
    def database_host_names(self):
        """
        Gets the database_host_names of this DatabaseInsightSummary.
        The hostnames for the database.


        :return: The database_host_names of this DatabaseInsightSummary.
        :rtype: list[str]
        """
        return self._database_host_names

    @database_host_names.setter
    def database_host_names(self, database_host_names):
        """
        Sets the database_host_names of this DatabaseInsightSummary.
        The hostnames for the database.


        :param database_host_names: The database_host_names of this DatabaseInsightSummary.
        :type: list[str]
        """
        self._database_host_names = database_host_names

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this DatabaseInsightSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this DatabaseInsightSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this DatabaseInsightSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this DatabaseInsightSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this DatabaseInsightSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this DatabaseInsightSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this DatabaseInsightSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this DatabaseInsightSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this DatabaseInsightSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this DatabaseInsightSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this DatabaseInsightSummary.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this DatabaseInsightSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    @property
    def entity_source(self):
        """
        **[Required]** Gets the entity_source of this DatabaseInsightSummary.
        Source of the database entity.

        Allowed values for this property are: "AUTONOMOUS_DATABASE", "EM_MANAGED_EXTERNAL_DATABASE", "MACS_MANAGED_EXTERNAL_DATABASE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The entity_source of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._entity_source

    @entity_source.setter
    def entity_source(self, entity_source):
        """
        Sets the entity_source of this DatabaseInsightSummary.
        Source of the database entity.


        :param entity_source: The entity_source of this DatabaseInsightSummary.
        :type: str
        """
        allowed_values = ["AUTONOMOUS_DATABASE", "EM_MANAGED_EXTERNAL_DATABASE", "MACS_MANAGED_EXTERNAL_DATABASE"]
        if not value_allowed_none_or_none_sentinel(entity_source, allowed_values):
            entity_source = 'UNKNOWN_ENUM_VALUE'
        self._entity_source = entity_source

    @property
    def processor_count(self):
        """
        Gets the processor_count of this DatabaseInsightSummary.
        Processor count. This is the OCPU count for Autonomous Database and CPU core count for other database types.


        :return: The processor_count of this DatabaseInsightSummary.
        :rtype: int
        """
        return self._processor_count

    @processor_count.setter
    def processor_count(self, processor_count):
        """
        Sets the processor_count of this DatabaseInsightSummary.
        Processor count. This is the OCPU count for Autonomous Database and CPU core count for other database types.


        :param processor_count: The processor_count of this DatabaseInsightSummary.
        :type: int
        """
        self._processor_count = processor_count

    @property
    def status(self):
        """
        Gets the status of this DatabaseInsightSummary.
        Indicates the status of a database insight in Operations Insights

        Allowed values for this property are: "DISABLED", "ENABLED", "TERMINATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DatabaseInsightSummary.
        Indicates the status of a database insight in Operations Insights


        :param status: The status of this DatabaseInsightSummary.
        :type: str
        """
        allowed_values = ["DISABLED", "ENABLED", "TERMINATED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def time_created(self):
        """
        Gets the time_created of this DatabaseInsightSummary.
        The time the the database insight was first enabled. An RFC3339 formatted datetime string


        :return: The time_created of this DatabaseInsightSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this DatabaseInsightSummary.
        The time the the database insight was first enabled. An RFC3339 formatted datetime string


        :param time_created: The time_created of this DatabaseInsightSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this DatabaseInsightSummary.
        The time the database insight was updated. An RFC3339 formatted datetime string


        :return: The time_updated of this DatabaseInsightSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this DatabaseInsightSummary.
        The time the database insight was updated. An RFC3339 formatted datetime string


        :param time_updated: The time_updated of this DatabaseInsightSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this DatabaseInsightSummary.
        The current state of the database.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this DatabaseInsightSummary.
        The current state of the database.


        :param lifecycle_state: The lifecycle_state of this DatabaseInsightSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "NEEDS_ATTENTION"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this DatabaseInsightSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this DatabaseInsightSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this DatabaseInsightSummary.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this DatabaseInsightSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .response_cache_lookup_policy import ResponseCacheLookupPolicy
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SimpleLookupPolicy(ResponseCacheLookupPolicy):
    """
    Provides ability to vary the cache key using context expressions.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SimpleLookupPolicy object with values from keyword arguments. The default value of the :py:attr:`~oci.apigateway.models.SimpleLookupPolicy.type` attribute
        of this class is ``SIMPLE_LOOKUP_POLICY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this SimpleLookupPolicy.
            Allowed values for this property are: "SIMPLE_LOOKUP_POLICY"
        :type type: str

        :param is_enabled:
            The value to assign to the is_enabled property of this SimpleLookupPolicy.
        :type is_enabled: bool

        :param is_private_caching_enabled:
            The value to assign to the is_private_caching_enabled property of this SimpleLookupPolicy.
        :type is_private_caching_enabled: bool

        :param cache_key_additions:
            The value to assign to the cache_key_additions property of this SimpleLookupPolicy.
        :type cache_key_additions: list[str]

        """
        self.swagger_types = {
            'type': 'str',
            'is_enabled': 'bool',
            'is_private_caching_enabled': 'bool',
            'cache_key_additions': 'list[str]'
        }

        self.attribute_map = {
            'type': 'type',
            'is_enabled': 'isEnabled',
            'is_private_caching_enabled': 'isPrivateCachingEnabled',
            'cache_key_additions': 'cacheKeyAdditions'
        }

        self._type = None
        self._is_enabled = None
        self._is_private_caching_enabled = None
        self._cache_key_additions = None
        self._type = 'SIMPLE_LOOKUP_POLICY'

    @property
    def cache_key_additions(self):
        """
        Gets the cache_key_additions of this SimpleLookupPolicy.
        A list of context expressions whose values will be added to the base cache key. Values should contain an expression enclosed within
        ${} delimiters. Only the request context is available.


        :return: The cache_key_additions of this SimpleLookupPolicy.
        :rtype: list[str]
        """
        return self._cache_key_additions

    @cache_key_additions.setter
    def cache_key_additions(self, cache_key_additions):
        """
        Sets the cache_key_additions of this SimpleLookupPolicy.
        A list of context expressions whose values will be added to the base cache key. Values should contain an expression enclosed within
        ${} delimiters. Only the request context is available.


        :param cache_key_additions: The cache_key_additions of this SimpleLookupPolicy.
        :type: list[str]
        """
        self._cache_key_additions = cache_key_additions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LimitDefinitionSummary(object):
    """
    The metadata specific to a resource limit definition.
    """

    #: A constant which can be used with the scope_type property of a LimitDefinitionSummary.
    #: This constant has a value of "GLOBAL"
    SCOPE_TYPE_GLOBAL = "GLOBAL"

    #: A constant which can be used with the scope_type property of a LimitDefinitionSummary.
    #: This constant has a value of "REGION"
    SCOPE_TYPE_REGION = "REGION"

    #: A constant which can be used with the scope_type property of a LimitDefinitionSummary.
    #: This constant has a value of "AD"
    SCOPE_TYPE_AD = "AD"

    def __init__(self, **kwargs):
        """
        Initializes a new LimitDefinitionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this LimitDefinitionSummary.
        :type name: str

        :param service_name:
            The value to assign to the service_name property of this LimitDefinitionSummary.
        :type service_name: str

        :param description:
            The value to assign to the description property of this LimitDefinitionSummary.
        :type description: str

        :param scope_type:
            The value to assign to the scope_type property of this LimitDefinitionSummary.
            Allowed values for this property are: "GLOBAL", "REGION", "AD", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type scope_type: str

        :param are_quotas_supported:
            The value to assign to the are_quotas_supported property of this LimitDefinitionSummary.
        :type are_quotas_supported: bool

        :param is_resource_availability_supported:
            The value to assign to the is_resource_availability_supported property of this LimitDefinitionSummary.
        :type is_resource_availability_supported: bool

        :param is_deprecated:
            The value to assign to the is_deprecated property of this LimitDefinitionSummary.
        :type is_deprecated: bool

        :param is_eligible_for_limit_increase:
            The value to assign to the is_eligible_for_limit_increase property of this LimitDefinitionSummary.
        :type is_eligible_for_limit_increase: bool

        :param is_dynamic:
            The value to assign to the is_dynamic property of this LimitDefinitionSummary.
        :type is_dynamic: bool

        """
        self.swagger_types = {
            'name': 'str',
            'service_name': 'str',
            'description': 'str',
            'scope_type': 'str',
            'are_quotas_supported': 'bool',
            'is_resource_availability_supported': 'bool',
            'is_deprecated': 'bool',
            'is_eligible_for_limit_increase': 'bool',
            'is_dynamic': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'service_name': 'serviceName',
            'description': 'description',
            'scope_type': 'scopeType',
            'are_quotas_supported': 'areQuotasSupported',
            'is_resource_availability_supported': 'isResourceAvailabilitySupported',
            'is_deprecated': 'isDeprecated',
            'is_eligible_for_limit_increase': 'isEligibleForLimitIncrease',
            'is_dynamic': 'isDynamic'
        }

        self._name = None
        self._service_name = None
        self._description = None
        self._scope_type = None
        self._are_quotas_supported = None
        self._is_resource_availability_supported = None
        self._is_deprecated = None
        self._is_eligible_for_limit_increase = None
        self._is_dynamic = None

    @property
    def name(self):
        """
        Gets the name of this LimitDefinitionSummary.
        The resource limit name. To be used for writing policies (in case of quotas) or other programmatic calls.


        :return: The name of this LimitDefinitionSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LimitDefinitionSummary.
        The resource limit name. To be used for writing policies (in case of quotas) or other programmatic calls.


        :param name: The name of this LimitDefinitionSummary.
        :type: str
        """
        self._name = name

    @property
    def service_name(self):
        """
        Gets the service_name of this LimitDefinitionSummary.
        The service name of the limit.


        :return: The service_name of this LimitDefinitionSummary.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this LimitDefinitionSummary.
        The service name of the limit.


        :param service_name: The service_name of this LimitDefinitionSummary.
        :type: str
        """
        self._service_name = service_name

    @property
    def description(self):
        """
        Gets the description of this LimitDefinitionSummary.
        The limit description.


        :return: The description of this LimitDefinitionSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this LimitDefinitionSummary.
        The limit description.


        :param description: The description of this LimitDefinitionSummary.
        :type: str
        """
        self._description = description

    @property
    def scope_type(self):
        """
        Gets the scope_type of this LimitDefinitionSummary.
        Reflects the scope of the resource limit, whether Global (across all regions), regional, or availability domain-specific.

        Allowed values for this property are: "GLOBAL", "REGION", "AD", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The scope_type of this LimitDefinitionSummary.
        :rtype: str
        """
        return self._scope_type

    @scope_type.setter
    def scope_type(self, scope_type):
        """
        Sets the scope_type of this LimitDefinitionSummary.
        Reflects the scope of the resource limit, whether Global (across all regions), regional, or availability domain-specific.


        :param scope_type: The scope_type of this LimitDefinitionSummary.
        :type: str
        """
        allowed_values = ["GLOBAL", "REGION", "AD"]
        if not value_allowed_none_or_none_sentinel(scope_type, allowed_values):
            scope_type = 'UNKNOWN_ENUM_VALUE'
        self._scope_type = scope_type

    @property
    def are_quotas_supported(self):
        """
        Gets the are_quotas_supported of this LimitDefinitionSummary.
        If true, quota policies can be created on top of this resource limit.


        :return: The are_quotas_supported of this LimitDefinitionSummary.
        :rtype: bool
        """
        return self._are_quotas_supported

    @are_quotas_supported.setter
    def are_quotas_supported(self, are_quotas_supported):
        """
        Sets the are_quotas_supported of this LimitDefinitionSummary.
        If true, quota policies can be created on top of this resource limit.


        :param are_quotas_supported: The are_quotas_supported of this LimitDefinitionSummary.
        :type: bool
        """
        self._are_quotas_supported = are_quotas_supported

    @property
    def is_resource_availability_supported(self):
        """
        Gets the is_resource_availability_supported of this LimitDefinitionSummary.
        Reflects whether or not the GetResourceAvailability API is supported for this limit.
        If not, the API returns an empty JSON response.


        :return: The is_resource_availability_supported of this LimitDefinitionSummary.
        :rtype: bool
        """
        return self._is_resource_availability_supported

    @is_resource_availability_supported.setter
    def is_resource_availability_supported(self, is_resource_availability_supported):
        """
        Sets the is_resource_availability_supported of this LimitDefinitionSummary.
        Reflects whether or not the GetResourceAvailability API is supported for this limit.
        If not, the API returns an empty JSON response.


        :param is_resource_availability_supported: The is_resource_availability_supported of this LimitDefinitionSummary.
        :type: bool
        """
        self._is_resource_availability_supported = is_resource_availability_supported

    @property
    def is_deprecated(self):
        """
        Gets the is_deprecated of this LimitDefinitionSummary.
        Indicates if the limit has been deprecated.


        :return: The is_deprecated of this LimitDefinitionSummary.
        :rtype: bool
        """
        return self._is_deprecated

    @is_deprecated.setter
    def is_deprecated(self, is_deprecated):
        """
        Sets the is_deprecated of this LimitDefinitionSummary.
        Indicates if the limit has been deprecated.


        :param is_deprecated: The is_deprecated of this LimitDefinitionSummary.
        :type: bool
        """
        self._is_deprecated = is_deprecated

    @property
    def is_eligible_for_limit_increase(self):
        """
        Gets the is_eligible_for_limit_increase of this LimitDefinitionSummary.
        Indicates if the customer can request a limit increase for this resource.


        :return: The is_eligible_for_limit_increase of this LimitDefinitionSummary.
        :rtype: bool
        """
        return self._is_eligible_for_limit_increase

    @is_eligible_for_limit_increase.setter
    def is_eligible_for_limit_increase(self, is_eligible_for_limit_increase):
        """
        Sets the is_eligible_for_limit_increase of this LimitDefinitionSummary.
        Indicates if the customer can request a limit increase for this resource.


        :param is_eligible_for_limit_increase: The is_eligible_for_limit_increase of this LimitDefinitionSummary.
        :type: bool
        """
        self._is_eligible_for_limit_increase = is_eligible_for_limit_increase

    @property
    def is_dynamic(self):
        """
        Gets the is_dynamic of this LimitDefinitionSummary.
        The limit for this resource has a dynamic value that is based on consumption across all OCI services.


        :return: The is_dynamic of this LimitDefinitionSummary.
        :rtype: bool
        """
        return self._is_dynamic

    @is_dynamic.setter
    def is_dynamic(self, is_dynamic):
        """
        Sets the is_dynamic of this LimitDefinitionSummary.
        The limit for this resource has a dynamic value that is based on consumption across all OCI services.


        :param is_dynamic: The is_dynamic of this LimitDefinitionSummary.
        :type: bool
        """
        self._is_dynamic = is_dynamic

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Folder(object):
    """
    A generic term used in the data catalog for an external organization concept used for a collection of data entities
    or processes within a data asset. This term is an internal term which models multiple external types of folder,
    such as file directories, database schemas, and so on. Some data assets, such as Object Store containers, may contain
    many levels of folders.
    """

    #: A constant which can be used with the lifecycle_state property of a Folder.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Folder.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Folder.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Folder.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Folder.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Folder.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Folder.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Folder.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    #: A constant which can be used with the harvest_status property of a Folder.
    #: This constant has a value of "COMPLETE"
    HARVEST_STATUS_COMPLETE = "COMPLETE"

    #: A constant which can be used with the harvest_status property of a Folder.
    #: This constant has a value of "ERROR"
    HARVEST_STATUS_ERROR = "ERROR"

    #: A constant which can be used with the harvest_status property of a Folder.
    #: This constant has a value of "IN_PROGRESS"
    HARVEST_STATUS_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the harvest_status property of a Folder.
    #: This constant has a value of "DEFERRED"
    HARVEST_STATUS_DEFERRED = "DEFERRED"

    def __init__(self, **kwargs):
        """
        Initializes a new Folder object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Folder.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this Folder.
        :type display_name: str

        :param business_name:
            The value to assign to the business_name property of this Folder.
        :type business_name: str

        :param description:
            The value to assign to the description property of this Folder.
        :type description: str

        :param parent_folder_key:
            The value to assign to the parent_folder_key property of this Folder.
        :type parent_folder_key: str

        :param type_key:
            The value to assign to the type_key property of this Folder.
        :type type_key: str

        :param time_harvested:
            The value to assign to the time_harvested property of this Folder.
        :type time_harvested: datetime

        :param object_relationships:
            The value to assign to the object_relationships property of this Folder.
        :type object_relationships: list[oci.data_catalog.models.ObjectRelationship]

        :param path:
            The value to assign to the path property of this Folder.
        :type path: str

        :param data_asset_key:
            The value to assign to the data_asset_key property of this Folder.
        :type data_asset_key: str

        :param custom_property_members:
            The value to assign to the custom_property_members property of this Folder.
        :type custom_property_members: list[oci.data_catalog.models.CustomPropertyGetUsage]

        :param properties:
            The value to assign to the properties property of this Folder.
        :type properties: dict(str, dict(str, str))

        :param external_key:
            The value to assign to the external_key property of this Folder.
        :type external_key: str

        :param time_created:
            The value to assign to the time_created property of this Folder.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Folder.
        :type time_updated: datetime

        :param created_by_id:
            The value to assign to the created_by_id property of this Folder.
        :type created_by_id: str

        :param updated_by_id:
            The value to assign to the updated_by_id property of this Folder.
        :type updated_by_id: str

        :param time_external:
            The value to assign to the time_external property of this Folder.
        :type time_external: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Folder.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param harvest_status:
            The value to assign to the harvest_status property of this Folder.
            Allowed values for this property are: "COMPLETE", "ERROR", "IN_PROGRESS", "DEFERRED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type harvest_status: str

        :param last_job_key:
            The value to assign to the last_job_key property of this Folder.
        :type last_job_key: str

        :param uri:
            The value to assign to the uri property of this Folder.
        :type uri: str

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'business_name': 'str',
            'description': 'str',
            'parent_folder_key': 'str',
            'type_key': 'str',
            'time_harvested': 'datetime',
            'object_relationships': 'list[ObjectRelationship]',
            'path': 'str',
            'data_asset_key': 'str',
            'custom_property_members': 'list[CustomPropertyGetUsage]',
            'properties': 'dict(str, dict(str, str))',
            'external_key': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'created_by_id': 'str',
            'updated_by_id': 'str',
            'time_external': 'datetime',
            'lifecycle_state': 'str',
            'harvest_status': 'str',
            'last_job_key': 'str',
            'uri': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'business_name': 'businessName',
            'description': 'description',
            'parent_folder_key': 'parentFolderKey',
            'type_key': 'typeKey',
            'time_harvested': 'timeHarvested',
            'object_relationships': 'objectRelationships',
            'path': 'path',
            'data_asset_key': 'dataAssetKey',
            'custom_property_members': 'customPropertyMembers',
            'properties': 'properties',
            'external_key': 'externalKey',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'created_by_id': 'createdById',
            'updated_by_id': 'updatedById',
            'time_external': 'timeExternal',
            'lifecycle_state': 'lifecycleState',
            'harvest_status': 'harvestStatus',
            'last_job_key': 'lastJobKey',
            'uri': 'uri'
        }

        self._key = None
        self._display_name = None
        self._business_name = None
        self._description = None
        self._parent_folder_key = None
        self._type_key = None
        self._time_harvested = None
        self._object_relationships = None
        self._path = None
        self._data_asset_key = None
        self._custom_property_members = None
        self._properties = None
        self._external_key = None
        self._time_created = None
        self._time_updated = None
        self._created_by_id = None
        self._updated_by_id = None
        self._time_external = None
        self._lifecycle_state = None
        self._harvest_status = None
        self._last_job_key = None
        self._uri = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this Folder.
        Unique folder key that is immutable.


        :return: The key of this Folder.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Folder.
        Unique folder key that is immutable.


        :param key: The key of this Folder.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        Gets the display_name of this Folder.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this Folder.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Folder.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this Folder.
        :type: str
        """
        self._display_name = display_name

    @property
    def business_name(self):
        """
        Gets the business_name of this Folder.
        Optional user friendly business name of the folder. If set, this supplements the harvested display name of the object.


        :return: The business_name of this Folder.
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """
        Sets the business_name of this Folder.
        Optional user friendly business name of the folder. If set, this supplements the harvested display name of the object.


        :param business_name: The business_name of this Folder.
        :type: str
        """
        self._business_name = business_name

    @property
    def description(self):
        """
        Gets the description of this Folder.
        Detailed description of a folder.


        :return: The description of this Folder.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Folder.
        Detailed description of a folder.


        :param description: The description of this Folder.
        :type: str
        """
        self._description = description

    @property
    def parent_folder_key(self):
        """
        Gets the parent_folder_key of this Folder.
        The unique key of the containing folder or null if there is no parent folder.


        :return: The parent_folder_key of this Folder.
        :rtype: str
        """
        return self._parent_folder_key

    @parent_folder_key.setter
    def parent_folder_key(self, parent_folder_key):
        """
        Sets the parent_folder_key of this Folder.
        The unique key of the containing folder or null if there is no parent folder.


        :param parent_folder_key: The parent_folder_key of this Folder.
        :type: str
        """
        self._parent_folder_key = parent_folder_key

    @property
    def type_key(self):
        """
        Gets the type_key of this Folder.
        The type of folder object. Type keys can be found via the '/types' endpoint.


        :return: The type_key of this Folder.
        :rtype: str
        """
        return self._type_key

    @type_key.setter
    def type_key(self, type_key):
        """
        Sets the type_key of this Folder.
        The type of folder object. Type keys can be found via the '/types' endpoint.


        :param type_key: The type_key of this Folder.
        :type: str
        """
        self._type_key = type_key

    @property
    def time_harvested(self):
        """
        Gets the time_harvested of this Folder.
        The date and time the folder was harvested, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_harvested of this Folder.
        :rtype: datetime
        """
        return self._time_harvested

    @time_harvested.setter
    def time_harvested(self, time_harvested):
        """
        Sets the time_harvested of this Folder.
        The date and time the folder was harvested, in the format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_harvested: The time_harvested of this Folder.
        :type: datetime
        """
        self._time_harvested = time_harvested

    @property
    def object_relationships(self):
        """
        Gets the object_relationships of this Folder.
        List of objects and their relationships to this folder.


        :return: The object_relationships of this Folder.
        :rtype: list[oci.data_catalog.models.ObjectRelationship]
        """
        return self._object_relationships

    @object_relationships.setter
    def object_relationships(self, object_relationships):
        """
        Sets the object_relationships of this Folder.
        List of objects and their relationships to this folder.


        :param object_relationships: The object_relationships of this Folder.
        :type: list[oci.data_catalog.models.ObjectRelationship]
        """
        self._object_relationships = object_relationships

    @property
    def path(self):
        """
        Gets the path of this Folder.
        Full path of the folder.


        :return: The path of this Folder.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this Folder.
        Full path of the folder.


        :param path: The path of this Folder.
        :type: str
        """
        self._path = path

    @property
    def data_asset_key(self):
        """
        Gets the data_asset_key of this Folder.
        The key of the associated data asset.


        :return: The data_asset_key of this Folder.
        :rtype: str
        """
        return self._data_asset_key

    @data_asset_key.setter
    def data_asset_key(self, data_asset_key):
        """
        Sets the data_asset_key of this Folder.
        The key of the associated data asset.


        :param data_asset_key: The data_asset_key of this Folder.
        :type: str
        """
        self._data_asset_key = data_asset_key

    @property
    def custom_property_members(self):
        """
        Gets the custom_property_members of this Folder.
        The list of customized properties along with the values for this object


        :return: The custom_property_members of this Folder.
        :rtype: list[oci.data_catalog.models.CustomPropertyGetUsage]
        """
        return self._custom_property_members

    @custom_property_members.setter
    def custom_property_members(self, custom_property_members):
        """
        Sets the custom_property_members of this Folder.
        The list of customized properties along with the values for this object


        :param custom_property_members: The custom_property_members of this Folder.
        :type: list[oci.data_catalog.models.CustomPropertyGetUsage]
        """
        self._custom_property_members = custom_property_members

    @property
    def properties(self):
        """
        Gets the properties of this Folder.
        A map of maps that contains the properties which are specific to the folder type. Each folder type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        folders have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`


        :return: The properties of this Folder.
        :rtype: dict(str, dict(str, str))
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this Folder.
        A map of maps that contains the properties which are specific to the folder type. Each folder type
        definition defines it's set of required and optional properties. The map keys are category names and the
        values are maps of property name to property value. Every property is contained inside of a category. Most
        folders have required properties within the \"default\" category.
        Example: `{\"properties\": { \"default\": { \"key1\": \"value1\"}}}`


        :param properties: The properties of this Folder.
        :type: dict(str, dict(str, str))
        """
        self._properties = properties

    @property
    def external_key(self):
        """
        Gets the external_key of this Folder.
        Unique external key of this object in the source system.


        :return: The external_key of this Folder.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this Folder.
        Unique external key of this object in the source system.


        :param external_key: The external_key of this Folder.
        :type: str
        """
        self._external_key = external_key

    @property
    def time_created(self):
        """
        Gets the time_created of this Folder.
        The date and time the folder was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Folder.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Folder.
        The date and time the folder was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Folder.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Folder.
        The last time that any change was made to the folder. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Folder.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Folder.
        The last time that any change was made to the folder. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Folder.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this Folder.
        OCID of the user who created the folder.


        :return: The created_by_id of this Folder.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this Folder.
        OCID of the user who created the folder.


        :param created_by_id: The created_by_id of this Folder.
        :type: str
        """
        self._created_by_id = created_by_id

    @property
    def updated_by_id(self):
        """
        Gets the updated_by_id of this Folder.
        OCID of the user who modified the folder.


        :return: The updated_by_id of this Folder.
        :rtype: str
        """
        return self._updated_by_id

    @updated_by_id.setter
    def updated_by_id(self, updated_by_id):
        """
        Sets the updated_by_id of this Folder.
        OCID of the user who modified the folder.


        :param updated_by_id: The updated_by_id of this Folder.
        :type: str
        """
        self._updated_by_id = updated_by_id

    @property
    def time_external(self):
        """
        Gets the time_external of this Folder.
        Last modified timestamp of this object in the external system.


        :return: The time_external of this Folder.
        :rtype: datetime
        """
        return self._time_external

    @time_external.setter
    def time_external(self, time_external):
        """
        Sets the time_external of this Folder.
        Last modified timestamp of this object in the external system.


        :param time_external: The time_external of this Folder.
        :type: datetime
        """
        self._time_external = time_external

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Folder.
        The current state of the folder.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Folder.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Folder.
        The current state of the folder.


        :param lifecycle_state: The lifecycle_state of this Folder.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def harvest_status(self):
        """
        Gets the harvest_status of this Folder.
        Status of the object as updated by the harvest process.

        Allowed values for this property are: "COMPLETE", "ERROR", "IN_PROGRESS", "DEFERRED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The harvest_status of this Folder.
        :rtype: str
        """
        return self._harvest_status

    @harvest_status.setter
    def harvest_status(self, harvest_status):
        """
        Sets the harvest_status of this Folder.
        Status of the object as updated by the harvest process.


        :param harvest_status: The harvest_status of this Folder.
        :type: str
        """
        allowed_values = ["COMPLETE", "ERROR", "IN_PROGRESS", "DEFERRED"]
        if not value_allowed_none_or_none_sentinel(harvest_status, allowed_values):
            harvest_status = 'UNKNOWN_ENUM_VALUE'
        self._harvest_status = harvest_status

    @property
    def last_job_key(self):
        """
        Gets the last_job_key of this Folder.
        The key of the last harvest process to update the metadata of this object.


        :return: The last_job_key of this Folder.
        :rtype: str
        """
        return self._last_job_key

    @last_job_key.setter
    def last_job_key(self, last_job_key):
        """
        Sets the last_job_key of this Folder.
        The key of the last harvest process to update the metadata of this object.


        :param last_job_key: The last_job_key of this Folder.
        :type: str
        """
        self._last_job_key = last_job_key

    @property
    def uri(self):
        """
        Gets the uri of this Folder.
        URI to the folder instance in the API.


        :return: The uri of this Folder.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this Folder.
        URI to the folder instance in the API.


        :param uri: The uri of this Folder.
        :type: str
        """
        self._uri = uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateVolumeAttachmentDetails(object):
    """
    details for updating a volume attachment.
    """

    #: A constant which can be used with the iscsi_login_state property of a UpdateVolumeAttachmentDetails.
    #: This constant has a value of "UNKNOWN"
    ISCSI_LOGIN_STATE_UNKNOWN = "UNKNOWN"

    #: A constant which can be used with the iscsi_login_state property of a UpdateVolumeAttachmentDetails.
    #: This constant has a value of "LOGGING_IN"
    ISCSI_LOGIN_STATE_LOGGING_IN = "LOGGING_IN"

    #: A constant which can be used with the iscsi_login_state property of a UpdateVolumeAttachmentDetails.
    #: This constant has a value of "LOGIN_SUCCEEDED"
    ISCSI_LOGIN_STATE_LOGIN_SUCCEEDED = "LOGIN_SUCCEEDED"

    #: A constant which can be used with the iscsi_login_state property of a UpdateVolumeAttachmentDetails.
    #: This constant has a value of "LOGIN_FAILED"
    ISCSI_LOGIN_STATE_LOGIN_FAILED = "LOGIN_FAILED"

    #: A constant which can be used with the iscsi_login_state property of a UpdateVolumeAttachmentDetails.
    #: This constant has a value of "LOGGING_OUT"
    ISCSI_LOGIN_STATE_LOGGING_OUT = "LOGGING_OUT"

    #: A constant which can be used with the iscsi_login_state property of a UpdateVolumeAttachmentDetails.
    #: This constant has a value of "LOGOUT_SUCCEEDED"
    ISCSI_LOGIN_STATE_LOGOUT_SUCCEEDED = "LOGOUT_SUCCEEDED"

    #: A constant which can be used with the iscsi_login_state property of a UpdateVolumeAttachmentDetails.
    #: This constant has a value of "LOGOUT_FAILED"
    ISCSI_LOGIN_STATE_LOGOUT_FAILED = "LOGOUT_FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateVolumeAttachmentDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param iscsi_login_state:
            The value to assign to the iscsi_login_state property of this UpdateVolumeAttachmentDetails.
            Allowed values for this property are: "UNKNOWN", "LOGGING_IN", "LOGIN_SUCCEEDED", "LOGIN_FAILED", "LOGGING_OUT", "LOGOUT_SUCCEEDED", "LOGOUT_FAILED"
        :type iscsi_login_state: str

        """
        self.swagger_types = {
            'iscsi_login_state': 'str'
        }

        self.attribute_map = {
            'iscsi_login_state': 'iscsiLoginState'
        }

        self._iscsi_login_state = None

    @property
    def iscsi_login_state(self):
        """
        Gets the iscsi_login_state of this UpdateVolumeAttachmentDetails.
        The iscsi login state of the volume attachment. For a multipath volume attachment,
        all iscsi sessions need to be all logged-in or logged-out to be in logged-in or logged-out state.

        Allowed values for this property are: "UNKNOWN", "LOGGING_IN", "LOGIN_SUCCEEDED", "LOGIN_FAILED", "LOGGING_OUT", "LOGOUT_SUCCEEDED", "LOGOUT_FAILED"


        :return: The iscsi_login_state of this UpdateVolumeAttachmentDetails.
        :rtype: str
        """
        return self._iscsi_login_state

    @iscsi_login_state.setter
    def iscsi_login_state(self, iscsi_login_state):
        """
        Sets the iscsi_login_state of this UpdateVolumeAttachmentDetails.
        The iscsi login state of the volume attachment. For a multipath volume attachment,
        all iscsi sessions need to be all logged-in or logged-out to be in logged-in or logged-out state.


        :param iscsi_login_state: The iscsi_login_state of this UpdateVolumeAttachmentDetails.
        :type: str
        """
        allowed_values = ["UNKNOWN", "LOGGING_IN", "LOGIN_SUCCEEDED", "LOGIN_FAILED", "LOGGING_OUT", "LOGOUT_SUCCEEDED", "LOGOUT_FAILED"]
        if not value_allowed_none_or_none_sentinel(iscsi_login_state, allowed_values):
            raise ValueError(
                "Invalid value for `iscsi_login_state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._iscsi_login_state = iscsi_login_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ContainerRepository(object):
    """
    Container repository metadata.
    """

    #: A constant which can be used with the lifecycle_state property of a ContainerRepository.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a ContainerRepository.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ContainerRepository.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new ContainerRepository object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this ContainerRepository.
        :type compartment_id: str

        :param created_by:
            The value to assign to the created_by property of this ContainerRepository.
        :type created_by: str

        :param display_name:
            The value to assign to the display_name property of this ContainerRepository.
        :type display_name: str

        :param id:
            The value to assign to the id property of this ContainerRepository.
        :type id: str

        :param image_count:
            The value to assign to the image_count property of this ContainerRepository.
        :type image_count: int

        :param is_immutable:
            The value to assign to the is_immutable property of this ContainerRepository.
        :type is_immutable: bool

        :param is_public:
            The value to assign to the is_public property of this ContainerRepository.
        :type is_public: bool

        :param layer_count:
            The value to assign to the layer_count property of this ContainerRepository.
        :type layer_count: int

        :param layers_size_in_bytes:
            The value to assign to the layers_size_in_bytes property of this ContainerRepository.
        :type layers_size_in_bytes: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ContainerRepository.
            Allowed values for this property are: "AVAILABLE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param readme:
            The value to assign to the readme property of this ContainerRepository.
        :type readme: oci.artifacts.models.ContainerRepositoryReadme

        :param time_created:
            The value to assign to the time_created property of this ContainerRepository.
        :type time_created: datetime

        :param time_last_pushed:
            The value to assign to the time_last_pushed property of this ContainerRepository.
        :type time_last_pushed: datetime

        :param billable_size_in_gbs:
            The value to assign to the billable_size_in_gbs property of this ContainerRepository.
        :type billable_size_in_gbs: int

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'created_by': 'str',
            'display_name': 'str',
            'id': 'str',
            'image_count': 'int',
            'is_immutable': 'bool',
            'is_public': 'bool',
            'layer_count': 'int',
            'layers_size_in_bytes': 'int',
            'lifecycle_state': 'str',
            'readme': 'ContainerRepositoryReadme',
            'time_created': 'datetime',
            'time_last_pushed': 'datetime',
            'billable_size_in_gbs': 'int'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'created_by': 'createdBy',
            'display_name': 'displayName',
            'id': 'id',
            'image_count': 'imageCount',
            'is_immutable': 'isImmutable',
            'is_public': 'isPublic',
            'layer_count': 'layerCount',
            'layers_size_in_bytes': 'layersSizeInBytes',
            'lifecycle_state': 'lifecycleState',
            'readme': 'readme',
            'time_created': 'timeCreated',
            'time_last_pushed': 'timeLastPushed',
            'billable_size_in_gbs': 'billableSizeInGBs'
        }

        self._compartment_id = None
        self._created_by = None
        self._display_name = None
        self._id = None
        self._image_count = None
        self._is_immutable = None
        self._is_public = None
        self._layer_count = None
        self._layers_size_in_bytes = None
        self._lifecycle_state = None
        self._readme = None
        self._time_created = None
        self._time_last_pushed = None
        self._billable_size_in_gbs = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ContainerRepository.
        The OCID of the compartment in which the container repository exists.


        :return: The compartment_id of this ContainerRepository.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ContainerRepository.
        The OCID of the compartment in which the container repository exists.


        :param compartment_id: The compartment_id of this ContainerRepository.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def created_by(self):
        """
        **[Required]** Gets the created_by of this ContainerRepository.
        The id of the user or principal that created the resource.


        :return: The created_by of this ContainerRepository.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this ContainerRepository.
        The id of the user or principal that created the resource.


        :param created_by: The created_by of this ContainerRepository.
        :type: str
        """
        self._created_by = created_by

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ContainerRepository.
        The container repository name.


        :return: The display_name of this ContainerRepository.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ContainerRepository.
        The container repository name.


        :param display_name: The display_name of this ContainerRepository.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ContainerRepository.
        The `OCID`__ of the container repository.

        Example: `ocid1.containerrepo.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this ContainerRepository.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ContainerRepository.
        The `OCID`__ of the container repository.

        Example: `ocid1.containerrepo.oc1..exampleuniqueID`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this ContainerRepository.
        :type: str
        """
        self._id = id

    @property
    def image_count(self):
        """
        **[Required]** Gets the image_count of this ContainerRepository.
        Total number of images.


        :return: The image_count of this ContainerRepository.
        :rtype: int
        """
        return self._image_count

    @image_count.setter
    def image_count(self, image_count):
        """
        Sets the image_count of this ContainerRepository.
        Total number of images.


        :param image_count: The image_count of this ContainerRepository.
        :type: int
        """
        self._image_count = image_count

    @property
    def is_immutable(self):
        """
        **[Required]** Gets the is_immutable of this ContainerRepository.
        Whether the repository is immutable. Images cannot be overwritten in an immutable repository.


        :return: The is_immutable of this ContainerRepository.
        :rtype: bool
        """
        return self._is_immutable

    @is_immutable.setter
    def is_immutable(self, is_immutable):
        """
        Sets the is_immutable of this ContainerRepository.
        Whether the repository is immutable. Images cannot be overwritten in an immutable repository.


        :param is_immutable: The is_immutable of this ContainerRepository.
        :type: bool
        """
        self._is_immutable = is_immutable

    @property
    def is_public(self):
        """
        **[Required]** Gets the is_public of this ContainerRepository.
        Whether the repository is public. A public repository allows unauthenticated access.


        :return: The is_public of this ContainerRepository.
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """
        Sets the is_public of this ContainerRepository.
        Whether the repository is public. A public repository allows unauthenticated access.


        :param is_public: The is_public of this ContainerRepository.
        :type: bool
        """
        self._is_public = is_public

    @property
    def layer_count(self):
        """
        **[Required]** Gets the layer_count of this ContainerRepository.
        Total number of layers.


        :return: The layer_count of this ContainerRepository.
        :rtype: int
        """
        return self._layer_count

    @layer_count.setter
    def layer_count(self, layer_count):
        """
        Sets the layer_count of this ContainerRepository.
        Total number of layers.


        :param layer_count: The layer_count of this ContainerRepository.
        :type: int
        """
        self._layer_count = layer_count

    @property
    def layers_size_in_bytes(self):
        """
        **[Required]** Gets the layers_size_in_bytes of this ContainerRepository.
        Total storage in bytes consumed by layers.


        :return: The layers_size_in_bytes of this ContainerRepository.
        :rtype: int
        """
        return self._layers_size_in_bytes

    @layers_size_in_bytes.setter
    def layers_size_in_bytes(self, layers_size_in_bytes):
        """
        Sets the layers_size_in_bytes of this ContainerRepository.
        Total storage in bytes consumed by layers.


        :param layers_size_in_bytes: The layers_size_in_bytes of this ContainerRepository.
        :type: int
        """
        self._layers_size_in_bytes = layers_size_in_bytes

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ContainerRepository.
        The current state of the container repository.

        Allowed values for this property are: "AVAILABLE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ContainerRepository.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ContainerRepository.
        The current state of the container repository.


        :param lifecycle_state: The lifecycle_state of this ContainerRepository.
        :type: str
        """
        allowed_values = ["AVAILABLE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def readme(self):
        """
        Gets the readme of this ContainerRepository.

        :return: The readme of this ContainerRepository.
        :rtype: oci.artifacts.models.ContainerRepositoryReadme
        """
        return self._readme

    @readme.setter
    def readme(self, readme):
        """
        Sets the readme of this ContainerRepository.

        :param readme: The readme of this ContainerRepository.
        :type: oci.artifacts.models.ContainerRepositoryReadme
        """
        self._readme = readme

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ContainerRepository.
        An RFC 3339 timestamp indicating when the repository was created.


        :return: The time_created of this ContainerRepository.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ContainerRepository.
        An RFC 3339 timestamp indicating when the repository was created.


        :param time_created: The time_created of this ContainerRepository.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_last_pushed(self):
        """
        Gets the time_last_pushed of this ContainerRepository.
        An RFC 3339 timestamp indicating when an image was last pushed to the repository.


        :return: The time_last_pushed of this ContainerRepository.
        :rtype: datetime
        """
        return self._time_last_pushed

    @time_last_pushed.setter
    def time_last_pushed(self, time_last_pushed):
        """
        Sets the time_last_pushed of this ContainerRepository.
        An RFC 3339 timestamp indicating when an image was last pushed to the repository.


        :param time_last_pushed: The time_last_pushed of this ContainerRepository.
        :type: datetime
        """
        self._time_last_pushed = time_last_pushed

    @property
    def billable_size_in_gbs(self):
        """
        **[Required]** Gets the billable_size_in_gbs of this ContainerRepository.
        Total storage size in GBs that will be charged.


        :return: The billable_size_in_gbs of this ContainerRepository.
        :rtype: int
        """
        return self._billable_size_in_gbs

    @billable_size_in_gbs.setter
    def billable_size_in_gbs(self, billable_size_in_gbs):
        """
        Sets the billable_size_in_gbs of this ContainerRepository.
        Total storage size in GBs that will be charged.


        :param billable_size_in_gbs: The billable_size_in_gbs of this ContainerRepository.
        :type: int
        """
        self._billable_size_in_gbs = billable_size_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_auto_scaling_policy_details import CreateAutoScalingPolicyDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateThresholdPolicyDetails(CreateAutoScalingPolicyDetails):
    """
    Creation details for a threshold-based autoscaling policy.

    In a threshold-based autoscaling policy, an autoscaling action is triggered when a performance metric meets
    or exceeds a threshold.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateThresholdPolicyDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.autoscaling.models.CreateThresholdPolicyDetails.policy_type` attribute
        of this class is ``threshold`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param capacity:
            The value to assign to the capacity property of this CreateThresholdPolicyDetails.
        :type capacity: oci.autoscaling.models.Capacity

        :param display_name:
            The value to assign to the display_name property of this CreateThresholdPolicyDetails.
        :type display_name: str

        :param policy_type:
            The value to assign to the policy_type property of this CreateThresholdPolicyDetails.
        :type policy_type: str

        :param is_enabled:
            The value to assign to the is_enabled property of this CreateThresholdPolicyDetails.
        :type is_enabled: bool

        :param rules:
            The value to assign to the rules property of this CreateThresholdPolicyDetails.
        :type rules: list[oci.autoscaling.models.CreateConditionDetails]

        """
        self.swagger_types = {
            'capacity': 'Capacity',
            'display_name': 'str',
            'policy_type': 'str',
            'is_enabled': 'bool',
            'rules': 'list[CreateConditionDetails]'
        }

        self.attribute_map = {
            'capacity': 'capacity',
            'display_name': 'displayName',
            'policy_type': 'policyType',
            'is_enabled': 'isEnabled',
            'rules': 'rules'
        }

        self._capacity = None
        self._display_name = None
        self._policy_type = None
        self._is_enabled = None
        self._rules = None
        self._policy_type = 'threshold'

    @property
    def rules(self):
        """
        **[Required]** Gets the rules of this CreateThresholdPolicyDetails.

        :return: The rules of this CreateThresholdPolicyDetails.
        :rtype: list[oci.autoscaling.models.CreateConditionDetails]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this CreateThresholdPolicyDetails.

        :param rules: The rules of this CreateThresholdPolicyDetails.
        :type: list[oci.autoscaling.models.CreateConditionDetails]
        """
        self._rules = rules

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .operator import Operator
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Intersect(Operator):
    """
    The information about a intersect object.
    """

    #: A constant which can be used with the intersect_type property of a Intersect.
    #: This constant has a value of "NAME"
    INTERSECT_TYPE_NAME = "NAME"

    #: A constant which can be used with the intersect_type property of a Intersect.
    #: This constant has a value of "POSITION"
    INTERSECT_TYPE_POSITION = "POSITION"

    def __init__(self, **kwargs):
        """
        Initializes a new Intersect object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.Intersect.model_type` attribute
        of this class is ``INTERSECT_OPERATOR`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this Intersect.
            Allowed values for this property are: "SOURCE_OPERATOR", "FILTER_OPERATOR", "JOINER_OPERATOR", "AGGREGATOR_OPERATOR", "PROJECTION_OPERATOR", "TARGET_OPERATOR", "DISTINCT_OPERATOR", "SORT_OPERATOR", "UNION_OPERATOR", "INTERSECT_OPERATOR", "MINUS_OPERATOR", "MERGE_OPERATOR", "START_OPERATOR", "END_OPERATOR", "PIPELINE_OPERATOR", "TASK_OPERATOR", "EXPRESSION_OPERATOR", "LOOKUP_OPERATOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this Intersect.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this Intersect.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this Intersect.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this Intersect.
        :type name: str

        :param description:
            The value to assign to the description property of this Intersect.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this Intersect.
        :type object_version: int

        :param input_ports:
            The value to assign to the input_ports property of this Intersect.
        :type input_ports: list[oci.data_integration.models.InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this Intersect.
        :type output_ports: list[oci.data_integration.models.OutputPort]

        :param object_status:
            The value to assign to the object_status property of this Intersect.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this Intersect.
        :type identifier: str

        :param parameters:
            The value to assign to the parameters property of this Intersect.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this Intersect.
        :type op_config_values: oci.data_integration.models.ConfigValues

        :param intersect_type:
            The value to assign to the intersect_type property of this Intersect.
            Allowed values for this property are: "NAME", "POSITION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type intersect_type: str

        :param is_all:
            The value to assign to the is_all property of this Intersect.
        :type is_all: bool

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[OutputPort]',
            'object_status': 'int',
            'identifier': 'str',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues',
            'intersect_type': 'str',
            'is_all': 'bool'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues',
            'intersect_type': 'intersectType',
            'is_all': 'isAll'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._input_ports = None
        self._output_ports = None
        self._object_status = None
        self._identifier = None
        self._parameters = None
        self._op_config_values = None
        self._intersect_type = None
        self._is_all = None
        self._model_type = 'INTERSECT_OPERATOR'

    @property
    def intersect_type(self):
        """
        Gets the intersect_type of this Intersect.
        intersectType

        Allowed values for this property are: "NAME", "POSITION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The intersect_type of this Intersect.
        :rtype: str
        """
        return self._intersect_type

    @intersect_type.setter
    def intersect_type(self, intersect_type):
        """
        Sets the intersect_type of this Intersect.
        intersectType


        :param intersect_type: The intersect_type of this Intersect.
        :type: str
        """
        allowed_values = ["NAME", "POSITION"]
        if not value_allowed_none_or_none_sentinel(intersect_type, allowed_values):
            intersect_type = 'UNKNOWN_ENUM_VALUE'
        self._intersect_type = intersect_type

    @property
    def is_all(self):
        """
        Gets the is_all of this Intersect.
        The information about the intersect all.


        :return: The is_all of this Intersect.
        :rtype: bool
        """
        return self._is_all

    @is_all.setter
    def is_all(self, is_all):
        """
        Sets the is_all of this Intersect.
        The information about the intersect all.


        :param is_all: The is_all of this Intersect.
        :type: bool
        """
        self._is_all = is_all

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MeasuredBootEntry(object):
    """
    One Trusted Platform Module (TPM) Platform Configuration Register (PCR) entry. The entry might be measured during boot,
    or specified in a policy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MeasuredBootEntry object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param pcr_index:
            The value to assign to the pcr_index property of this MeasuredBootEntry.
        :type pcr_index: str

        :param value:
            The value to assign to the value property of this MeasuredBootEntry.
        :type value: str

        :param hash_algorithm:
            The value to assign to the hash_algorithm property of this MeasuredBootEntry.
        :type hash_algorithm: str

        """
        self.swagger_types = {
            'pcr_index': 'str',
            'value': 'str',
            'hash_algorithm': 'str'
        }

        self.attribute_map = {
            'pcr_index': 'pcrIndex',
            'value': 'value',
            'hash_algorithm': 'hashAlgorithm'
        }

        self._pcr_index = None
        self._value = None
        self._hash_algorithm = None

    @property
    def pcr_index(self):
        """
        Gets the pcr_index of this MeasuredBootEntry.
        The index of the policy.


        :return: The pcr_index of this MeasuredBootEntry.
        :rtype: str
        """
        return self._pcr_index

    @pcr_index.setter
    def pcr_index(self, pcr_index):
        """
        Sets the pcr_index of this MeasuredBootEntry.
        The index of the policy.


        :param pcr_index: The pcr_index of this MeasuredBootEntry.
        :type: str
        """
        self._pcr_index = pcr_index

    @property
    def value(self):
        """
        Gets the value of this MeasuredBootEntry.
        The hashed PCR value.


        :return: The value of this MeasuredBootEntry.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this MeasuredBootEntry.
        The hashed PCR value.


        :param value: The value of this MeasuredBootEntry.
        :type: str
        """
        self._value = value

    @property
    def hash_algorithm(self):
        """
        Gets the hash_algorithm of this MeasuredBootEntry.
        The type of algorithm used to calculate the hash.


        :return: The hash_algorithm of this MeasuredBootEntry.
        :rtype: str
        """
        return self._hash_algorithm

    @hash_algorithm.setter
    def hash_algorithm(self, hash_algorithm):
        """
        Sets the hash_algorithm of this MeasuredBootEntry.
        The type of algorithm used to calculate the hash.


        :param hash_algorithm: The hash_algorithm of this MeasuredBootEntry.
        :type: str
        """
        self._hash_algorithm = hash_algorithm

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateExternalPublicationDetails(object):
    """
    Properties used to update a published Oracle Cloud Infrastructure Data Flow object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateExternalPublicationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param application_id:
            The value to assign to the application_id property of this UpdateExternalPublicationDetails.
        :type application_id: str

        :param application_compartment_id:
            The value to assign to the application_compartment_id property of this UpdateExternalPublicationDetails.
        :type application_compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this UpdateExternalPublicationDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateExternalPublicationDetails.
        :type description: str

        :param resource_configuration:
            The value to assign to the resource_configuration property of this UpdateExternalPublicationDetails.
        :type resource_configuration: oci.data_integration.models.ResourceConfiguration

        :param configuration_details:
            The value to assign to the configuration_details property of this UpdateExternalPublicationDetails.
        :type configuration_details: oci.data_integration.models.ConfigurationDetails

        """
        self.swagger_types = {
            'application_id': 'str',
            'application_compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'resource_configuration': 'ResourceConfiguration',
            'configuration_details': 'ConfigurationDetails'
        }

        self.attribute_map = {
            'application_id': 'applicationId',
            'application_compartment_id': 'applicationCompartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'resource_configuration': 'resourceConfiguration',
            'configuration_details': 'configurationDetails'
        }

        self._application_id = None
        self._application_compartment_id = None
        self._display_name = None
        self._description = None
        self._resource_configuration = None
        self._configuration_details = None

    @property
    def application_id(self):
        """
        Gets the application_id of this UpdateExternalPublicationDetails.
        The unique OCID of the identifier that is returned after creating the Oracle Cloud Infrastructure Data Flow application.


        :return: The application_id of this UpdateExternalPublicationDetails.
        :rtype: str
        """
        return self._application_id

    @application_id.setter
    def application_id(self, application_id):
        """
        Sets the application_id of this UpdateExternalPublicationDetails.
        The unique OCID of the identifier that is returned after creating the Oracle Cloud Infrastructure Data Flow application.


        :param application_id: The application_id of this UpdateExternalPublicationDetails.
        :type: str
        """
        self._application_id = application_id

    @property
    def application_compartment_id(self):
        """
        **[Required]** Gets the application_compartment_id of this UpdateExternalPublicationDetails.
        The OCID of the compartment where the application is created in the Oracle Cloud Infrastructure Data Flow Service.


        :return: The application_compartment_id of this UpdateExternalPublicationDetails.
        :rtype: str
        """
        return self._application_compartment_id

    @application_compartment_id.setter
    def application_compartment_id(self, application_compartment_id):
        """
        Sets the application_compartment_id of this UpdateExternalPublicationDetails.
        The OCID of the compartment where the application is created in the Oracle Cloud Infrastructure Data Flow Service.


        :param application_compartment_id: The application_compartment_id of this UpdateExternalPublicationDetails.
        :type: str
        """
        self._application_compartment_id = application_compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this UpdateExternalPublicationDetails.
        The name of the application.


        :return: The display_name of this UpdateExternalPublicationDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateExternalPublicationDetails.
        The name of the application.


        :param display_name: The display_name of this UpdateExternalPublicationDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdateExternalPublicationDetails.
        The details of the data flow or the application.


        :return: The description of this UpdateExternalPublicationDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateExternalPublicationDetails.
        The details of the data flow or the application.


        :param description: The description of this UpdateExternalPublicationDetails.
        :type: str
        """
        self._description = description

    @property
    def resource_configuration(self):
        """
        Gets the resource_configuration of this UpdateExternalPublicationDetails.

        :return: The resource_configuration of this UpdateExternalPublicationDetails.
        :rtype: oci.data_integration.models.ResourceConfiguration
        """
        return self._resource_configuration

    @resource_configuration.setter
    def resource_configuration(self, resource_configuration):
        """
        Sets the resource_configuration of this UpdateExternalPublicationDetails.

        :param resource_configuration: The resource_configuration of this UpdateExternalPublicationDetails.
        :type: oci.data_integration.models.ResourceConfiguration
        """
        self._resource_configuration = resource_configuration

    @property
    def configuration_details(self):
        """
        Gets the configuration_details of this UpdateExternalPublicationDetails.

        :return: The configuration_details of this UpdateExternalPublicationDetails.
        :rtype: oci.data_integration.models.ConfigurationDetails
        """
        return self._configuration_details

    @configuration_details.setter
    def configuration_details(self, configuration_details):
        """
        Sets the configuration_details of this UpdateExternalPublicationDetails.

        :param configuration_details: The configuration_details of this UpdateExternalPublicationDetails.
        :type: oci.data_integration.models.ConfigurationDetails
        """
        self._configuration_details = configuration_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .monitor_configuration import MonitorConfiguration
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RestMonitorConfiguration(MonitorConfiguration):
    """
    Request configuration details for the REST monitor type.
    """

    #: A constant which can be used with the request_method property of a RestMonitorConfiguration.
    #: This constant has a value of "GET"
    REQUEST_METHOD_GET = "GET"

    #: A constant which can be used with the request_method property of a RestMonitorConfiguration.
    #: This constant has a value of "POST"
    REQUEST_METHOD_POST = "POST"

    #: A constant which can be used with the req_authentication_scheme property of a RestMonitorConfiguration.
    #: This constant has a value of "OAUTH"
    REQ_AUTHENTICATION_SCHEME_OAUTH = "OAUTH"

    #: A constant which can be used with the req_authentication_scheme property of a RestMonitorConfiguration.
    #: This constant has a value of "NONE"
    REQ_AUTHENTICATION_SCHEME_NONE = "NONE"

    #: A constant which can be used with the req_authentication_scheme property of a RestMonitorConfiguration.
    #: This constant has a value of "BASIC"
    REQ_AUTHENTICATION_SCHEME_BASIC = "BASIC"

    #: A constant which can be used with the req_authentication_scheme property of a RestMonitorConfiguration.
    #: This constant has a value of "BEARER"
    REQ_AUTHENTICATION_SCHEME_BEARER = "BEARER"

    def __init__(self, **kwargs):
        """
        Initializes a new RestMonitorConfiguration object with values from keyword arguments. The default value of the :py:attr:`~oci.apm_synthetics.models.RestMonitorConfiguration.config_type` attribute
        of this class is ``REST_CONFIG`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_type:
            The value to assign to the config_type property of this RestMonitorConfiguration.
            Allowed values for this property are: "BROWSER_CONFIG", "SCRIPTED_BROWSER_CONFIG", "REST_CONFIG", "SCRIPTED_REST_CONFIG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type config_type: str

        :param is_failure_retried:
            The value to assign to the is_failure_retried property of this RestMonitorConfiguration.
        :type is_failure_retried: bool

        :param is_redirection_enabled:
            The value to assign to the is_redirection_enabled property of this RestMonitorConfiguration.
        :type is_redirection_enabled: bool

        :param is_certificate_validation_enabled:
            The value to assign to the is_certificate_validation_enabled property of this RestMonitorConfiguration.
        :type is_certificate_validation_enabled: bool

        :param request_method:
            The value to assign to the request_method property of this RestMonitorConfiguration.
            Allowed values for this property are: "GET", "POST", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type request_method: str

        :param req_authentication_scheme:
            The value to assign to the req_authentication_scheme property of this RestMonitorConfiguration.
            Allowed values for this property are: "OAUTH", "NONE", "BASIC", "BEARER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type req_authentication_scheme: str

        :param req_authentication_details:
            The value to assign to the req_authentication_details property of this RestMonitorConfiguration.
        :type req_authentication_details: oci.apm_synthetics.models.RequestAuthenticationDetails

        :param request_headers:
            The value to assign to the request_headers property of this RestMonitorConfiguration.
        :type request_headers: list[oci.apm_synthetics.models.Header]

        :param request_query_params:
            The value to assign to the request_query_params property of this RestMonitorConfiguration.
        :type request_query_params: list[oci.apm_synthetics.models.RequestQueryParam]

        :param request_post_body:
            The value to assign to the request_post_body property of this RestMonitorConfiguration.
        :type request_post_body: str

        :param verify_response_content:
            The value to assign to the verify_response_content property of this RestMonitorConfiguration.
        :type verify_response_content: str

        :param verify_response_codes:
            The value to assign to the verify_response_codes property of this RestMonitorConfiguration.
        :type verify_response_codes: list[str]

        """
        self.swagger_types = {
            'config_type': 'str',
            'is_failure_retried': 'bool',
            'is_redirection_enabled': 'bool',
            'is_certificate_validation_enabled': 'bool',
            'request_method': 'str',
            'req_authentication_scheme': 'str',
            'req_authentication_details': 'RequestAuthenticationDetails',
            'request_headers': 'list[Header]',
            'request_query_params': 'list[RequestQueryParam]',
            'request_post_body': 'str',
            'verify_response_content': 'str',
            'verify_response_codes': 'list[str]'
        }

        self.attribute_map = {
            'config_type': 'configType',
            'is_failure_retried': 'isFailureRetried',
            'is_redirection_enabled': 'isRedirectionEnabled',
            'is_certificate_validation_enabled': 'isCertificateValidationEnabled',
            'request_method': 'requestMethod',
            'req_authentication_scheme': 'reqAuthenticationScheme',
            'req_authentication_details': 'reqAuthenticationDetails',
            'request_headers': 'requestHeaders',
            'request_query_params': 'requestQueryParams',
            'request_post_body': 'requestPostBody',
            'verify_response_content': 'verifyResponseContent',
            'verify_response_codes': 'verifyResponseCodes'
        }

        self._config_type = None
        self._is_failure_retried = None
        self._is_redirection_enabled = None
        self._is_certificate_validation_enabled = None
        self._request_method = None
        self._req_authentication_scheme = None
        self._req_authentication_details = None
        self._request_headers = None
        self._request_query_params = None
        self._request_post_body = None
        self._verify_response_content = None
        self._verify_response_codes = None
        self._config_type = 'REST_CONFIG'

    @property
    def is_redirection_enabled(self):
        """
        Gets the is_redirection_enabled of this RestMonitorConfiguration.
        If redirection enabled, then redirects will be allowed while accessing target URL.


        :return: The is_redirection_enabled of this RestMonitorConfiguration.
        :rtype: bool
        """
        return self._is_redirection_enabled

    @is_redirection_enabled.setter
    def is_redirection_enabled(self, is_redirection_enabled):
        """
        Sets the is_redirection_enabled of this RestMonitorConfiguration.
        If redirection enabled, then redirects will be allowed while accessing target URL.


        :param is_redirection_enabled: The is_redirection_enabled of this RestMonitorConfiguration.
        :type: bool
        """
        self._is_redirection_enabled = is_redirection_enabled

    @property
    def is_certificate_validation_enabled(self):
        """
        Gets the is_certificate_validation_enabled of this RestMonitorConfiguration.
        If certificate validation enabled, then call will fail for certificate errors.


        :return: The is_certificate_validation_enabled of this RestMonitorConfiguration.
        :rtype: bool
        """
        return self._is_certificate_validation_enabled

    @is_certificate_validation_enabled.setter
    def is_certificate_validation_enabled(self, is_certificate_validation_enabled):
        """
        Sets the is_certificate_validation_enabled of this RestMonitorConfiguration.
        If certificate validation enabled, then call will fail for certificate errors.


        :param is_certificate_validation_enabled: The is_certificate_validation_enabled of this RestMonitorConfiguration.
        :type: bool
        """
        self._is_certificate_validation_enabled = is_certificate_validation_enabled

    @property
    def request_method(self):
        """
        Gets the request_method of this RestMonitorConfiguration.
        Request HTTP method.

        Allowed values for this property are: "GET", "POST", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The request_method of this RestMonitorConfiguration.
        :rtype: str
        """
        return self._request_method

    @request_method.setter
    def request_method(self, request_method):
        """
        Sets the request_method of this RestMonitorConfiguration.
        Request HTTP method.


        :param request_method: The request_method of this RestMonitorConfiguration.
        :type: str
        """
        allowed_values = ["GET", "POST"]
        if not value_allowed_none_or_none_sentinel(request_method, allowed_values):
            request_method = 'UNKNOWN_ENUM_VALUE'
        self._request_method = request_method

    @property
    def req_authentication_scheme(self):
        """
        Gets the req_authentication_scheme of this RestMonitorConfiguration.
        Request http authentication scheme.

        Allowed values for this property are: "OAUTH", "NONE", "BASIC", "BEARER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The req_authentication_scheme of this RestMonitorConfiguration.
        :rtype: str
        """
        return self._req_authentication_scheme

    @req_authentication_scheme.setter
    def req_authentication_scheme(self, req_authentication_scheme):
        """
        Sets the req_authentication_scheme of this RestMonitorConfiguration.
        Request http authentication scheme.


        :param req_authentication_scheme: The req_authentication_scheme of this RestMonitorConfiguration.
        :type: str
        """
        allowed_values = ["OAUTH", "NONE", "BASIC", "BEARER"]
        if not value_allowed_none_or_none_sentinel(req_authentication_scheme, allowed_values):
            req_authentication_scheme = 'UNKNOWN_ENUM_VALUE'
        self._req_authentication_scheme = req_authentication_scheme

    @property
    def req_authentication_details(self):
        """
        Gets the req_authentication_details of this RestMonitorConfiguration.

        :return: The req_authentication_details of this RestMonitorConfiguration.
        :rtype: oci.apm_synthetics.models.RequestAuthenticationDetails
        """
        return self._req_authentication_details

    @req_authentication_details.setter
    def req_authentication_details(self, req_authentication_details):
        """
        Sets the req_authentication_details of this RestMonitorConfiguration.

        :param req_authentication_details: The req_authentication_details of this RestMonitorConfiguration.
        :type: oci.apm_synthetics.models.RequestAuthenticationDetails
        """
        self._req_authentication_details = req_authentication_details

    @property
    def request_headers(self):
        """
        Gets the request_headers of this RestMonitorConfiguration.
        List of request headers. Example: `[{\"headerName\": \"content-type\", \"headerValue\":\"json\"}]`


        :return: The request_headers of this RestMonitorConfiguration.
        :rtype: list[oci.apm_synthetics.models.Header]
        """
        return self._request_headers

    @request_headers.setter
    def request_headers(self, request_headers):
        """
        Sets the request_headers of this RestMonitorConfiguration.
        List of request headers. Example: `[{\"headerName\": \"content-type\", \"headerValue\":\"json\"}]`


        :param request_headers: The request_headers of this RestMonitorConfiguration.
        :type: list[oci.apm_synthetics.models.Header]
        """
        self._request_headers = request_headers

    @property
    def request_query_params(self):
        """
        Gets the request_query_params of this RestMonitorConfiguration.
        List of request query params. Example: `[{\"paramName\": \"sortOrder\", \"paramValue\": \"asc\"}]`


        :return: The request_query_params of this RestMonitorConfiguration.
        :rtype: list[oci.apm_synthetics.models.RequestQueryParam]
        """
        return self._request_query_params

    @request_query_params.setter
    def request_query_params(self, request_query_params):
        """
        Sets the request_query_params of this RestMonitorConfiguration.
        List of request query params. Example: `[{\"paramName\": \"sortOrder\", \"paramValue\": \"asc\"}]`


        :param request_query_params: The request_query_params of this RestMonitorConfiguration.
        :type: list[oci.apm_synthetics.models.RequestQueryParam]
        """
        self._request_query_params = request_query_params

    @property
    def request_post_body(self):
        """
        Gets the request_post_body of this RestMonitorConfiguration.
        Request post body content.


        :return: The request_post_body of this RestMonitorConfiguration.
        :rtype: str
        """
        return self._request_post_body

    @request_post_body.setter
    def request_post_body(self, request_post_body):
        """
        Sets the request_post_body of this RestMonitorConfiguration.
        Request post body content.


        :param request_post_body: The request_post_body of this RestMonitorConfiguration.
        :type: str
        """
        self._request_post_body = request_post_body

    @property
    def verify_response_content(self):
        """
        Gets the verify_response_content of this RestMonitorConfiguration.
        Verify response content against regular expression based string.
        If response content does not match the verifyResponseContent value, then it will be considered a failure.


        :return: The verify_response_content of this RestMonitorConfiguration.
        :rtype: str
        """
        return self._verify_response_content

    @verify_response_content.setter
    def verify_response_content(self, verify_response_content):
        """
        Sets the verify_response_content of this RestMonitorConfiguration.
        Verify response content against regular expression based string.
        If response content does not match the verifyResponseContent value, then it will be considered a failure.


        :param verify_response_content: The verify_response_content of this RestMonitorConfiguration.
        :type: str
        """
        self._verify_response_content = verify_response_content

    @property
    def verify_response_codes(self):
        """
        Gets the verify_response_codes of this RestMonitorConfiguration.
        Expected HTTP response codes. For status code range, set values such as 2xx, 3xx.


        :return: The verify_response_codes of this RestMonitorConfiguration.
        :rtype: list[str]
        """
        return self._verify_response_codes

    @verify_response_codes.setter
    def verify_response_codes(self, verify_response_codes):
        """
        Sets the verify_response_codes of this RestMonitorConfiguration.
        Expected HTTP response codes. For status code range, set values such as 2xx, 3xx.


        :param verify_response_codes: The verify_response_codes of this RestMonitorConfiguration.
        :type: list[str]
        """
        self._verify_response_codes = verify_response_codes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .credential_details import CredentialDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CredentialsBySource(CredentialDetails):
    """
    Credential Source to connect to the database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CredentialsBySource object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.CredentialsBySource.credential_type` attribute
        of this class is ``CREDENTIALS_BY_SOURCE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param credential_source_name:
            The value to assign to the credential_source_name property of this CredentialsBySource.
        :type credential_source_name: str

        :param credential_type:
            The value to assign to the credential_type property of this CredentialsBySource.
            Allowed values for this property are: "CREDENTIALS_BY_SOURCE"
        :type credential_type: str

        """
        self.swagger_types = {
            'credential_source_name': 'str',
            'credential_type': 'str'
        }

        self.attribute_map = {
            'credential_source_name': 'credentialSourceName',
            'credential_type': 'credentialType'
        }

        self._credential_source_name = None
        self._credential_type = None
        self._credential_type = 'CREDENTIALS_BY_SOURCE'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
